"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertTypeLeafNode = exports.isTypeLeafNode = exports.TypeLeafNode = void 0;
class TypeLeafNode {
    constructor(leaf) {
        this.nodeClass = 'TypeLeafNode';
        this.leaf = leaf;
    }
    static fromIdl(type) {
        switch (type) {
            case 'bool':
                return new TypeLeafNode({ kind: 'bool', prefix: 'u8' });
            case 'string':
                return new TypeLeafNode({ kind: 'string', prefix: 'u32' });
            case 'publicKey':
                return new TypeLeafNode({ kind: 'publicKey' });
            case 'bytes':
                return new TypeLeafNode({ kind: 'bytes' });
            default:
                return new TypeLeafNode({ kind: 'number', number: type });
        }
    }
    accept(visitor) {
        return visitor.visitTypeLeaf(this);
    }
    isSignedInteger() {
        return this.isNumber() && this.leaf.number.startsWith('i');
    }
    isUnsignedInteger() {
        return this.isNumber() && this.leaf.number.startsWith('u');
    }
    isInteger() {
        return this.isNumber() && !this.leaf.number.startsWith('f');
    }
    isDecimal() {
        return this.isNumber() && this.leaf.number.startsWith('f');
    }
    isNumber() {
        return this.leaf.kind === 'number';
    }
    toString() {
        switch (this.leaf.kind) {
            case 'number':
                return `number(${this.leaf.number})`;
            case 'fixedString':
                return `fixedString(${this.leaf.bytes})`;
            case 'string':
                return `string(${this.leaf.prefix})`;
            case 'bool':
                return `bool(${this.leaf.prefix})`;
            default:
                return this.leaf.kind;
        }
    }
}
exports.TypeLeafNode = TypeLeafNode;
function isTypeLeafNode(node) {
    return !!node && node.nodeClass === 'TypeLeafNode';
}
exports.isTypeLeafNode = isTypeLeafNode;
function assertTypeLeafNode(node) {
    var _a;
    if (!isTypeLeafNode(node)) {
        throw new Error(`Expected TypeLeafNode, got ${(_a = node === null || node === void 0 ? void 0 : node.nodeClass) !== null && _a !== void 0 ? _a : 'null'}.`);
    }
}
exports.assertTypeLeafNode = assertTypeLeafNode;
//# sourceMappingURL=TypeLeafNode.js.map