import type { IdlTypeLeaf } from '../idl';
import type { Visitable, Visitor } from '../visitors';
import type { Node } from './Node';
export type NumberLeafType = 'u8' | 'u16' | 'u32' | 'u64' | 'u128' | 'i8' | 'i16' | 'i32' | 'i64' | 'i128' | 'f32' | 'f64';
export type LeafType = {
    kind: 'number';
    number: NumberLeafType;
} | {
    kind: 'bool';
    prefix: NumberLeafType;
} | {
    kind: 'string';
    prefix: NumberLeafType;
} | {
    kind: 'fixedString';
    bytes: number;
} | {
    kind: 'variableString';
} | {
    kind: 'bytes';
} | {
    kind: 'publicKey';
};
export declare class TypeLeafNode implements Visitable {
    readonly nodeClass: "TypeLeafNode";
    readonly leaf: LeafType;
    constructor(leaf: LeafType);
    static fromIdl(type: IdlTypeLeaf): TypeLeafNode;
    accept<T>(visitor: Visitor<T>): T;
    isSignedInteger(): boolean;
    isUnsignedInteger(): boolean;
    isInteger(): boolean;
    isDecimal(): boolean;
    isNumber(): this is TypeLeafNode & {
        leaf: Extract<LeafType, {
            kind: 'number';
        }>;
    };
    toString(): string;
}
export declare function isTypeLeafNode(node: Node | null): node is TypeLeafNode;
export declare function assertTypeLeafNode(node: Node | null): asserts node is TypeLeafNode;
